Orange-Spectroscopy documentation
=================================

Orange-Spectroscopy is an add-on for Orange for the analysis of spectral data.

To use it, download and install the `Quasar distribution of Orange
<https://quasar.codes/>`_, which comes with Orange-Spectroscopy pre-installed.
You can also install it into your `Orange <https://orange.biolab.si/>`_
data mining suite with the "Add-ons" menu (Options->Add-ons).

For an introduction to Orange and widgets from this add-on, see
the following YouTube channels:

* `Getting started with Orange <https://www.youtube.com/playlist?list=PLmNPvQr9Tf-ZSDLwOzxpvY-HrE0yv-8Fy>`_ -
  introduces data analysis with Orange
* `Spectral Orange <https://www.youtube.com/playlist?list=PLmNPvQr9Tf-bPWjDJvJBPZJ6us_KTAD5T>`_ -
  tutorials that use the Spectroscopy add-on on spectral data


Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/spectra
   widgets/hyperspectra
   widgets/interpolate
   widgets/preprocess-spectra
   widgets/integrate-spectra
   widgets/multifile
   widgets/tilefile
   widgets/average
   widgets/interferogram-to-spectrum
   widgets/reshape-map
   widgets/pls
   widgets/peakfit
   widgets/snr

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

